==> haskell-uuid-types-1.0.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid-types
version:              1.0.3
visibility:           public
id:                   uuid-types-1.0.3-46TWIxSMnBvCc0JYq0vbN4
key:                  uuid-types-1.0.3-46TWIxSMnBvCc0JYq0vbN4
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           aslatter@gmail.com
author:               Antoine Latter
homepage:             https://github.com/aslatter/uuid
synopsis:             Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  577b7a3c41ca342179cb824ac78a6c9a
exposed:              True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder

import-dirs:          /usr/lib/ghc-8.8.3/site-local/uuid-types-1.0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/uuid-types-1.0.3
hs-libraries:         HSuuid-types-1.0.3-46TWIxSMnBvCc0JYq0vbN4
depends:
    base-4.13.0.0 binary-0.8.7.0 bytestring-0.10.10.0 deepseq-1.4.4.0
    hashable-1.3.0.0-JbFSy8XBnx7GEc7vKlz2Jl
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy text-1.2.4.0

haddock-interfaces:   /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html:         /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uuid-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uuid-types
version:              1.0.3
visibility:           public
id:                   uuid-types-1.0.3-CRmROUkUzZy5R393GhetWg
key:                  uuid-types-1.0.3-CRmROUkUzZy5R393GhetWg
license:              BSD-3-Clause
copyright:            (c) 2008-2014 Antoine Latter
maintainer:           aslatter@gmail.com
author:               Antoine Latter
homepage:             https://github.com/aslatter/uuid
synopsis:             Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.

category:             Data
abi:                  26cff3628dac3fc5cf53f8c7b64017e0
exposed:              True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal
    Data.UUID.Types.Internal.Builder

import-dirs:          /usr/lib/ghc-8.8.3/site-local/uuid-types-1.0.3
library-dirs:         /usr/lib/ghc-8.8.3/site-local/uuid-types-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/uuid-types-1.0.3
hs-libraries:         HSuuid-types-1.0.3-CRmROUkUzZy5R393GhetWg
depends:
    base-4.13.0.0 binary-0.8.7.0 bytestring-0.10.10.0 deepseq-1.4.4.0
    hashable-1.3.0.0-GFyEr4gS8CZEgl3N6WrORB
    random-1.1-CUqV1zxrwrE4K5XCdTZSYy text-1.2.4.0

haddock-interfaces:   /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html:         /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
